import * as Config from '@/common/config.js'
import * as Storage from '@/common/storage.js'

export const getNowTime = () => {
    return Math.ceil(Date.now() / 1000)
}

export const formatNumber = (number) => {
    number = number.toString()
    return number[1] ? number : '0' + number
}

export const formatDuration = (number) => {
    let result = '00:00'
    if (number > 0) {
        let hours = Math.floor(number / 3600)
        let minutes = Math.floor((number - hours * 3600) / 60)
        let seconds = number % 60
        let format = []
        if (hours > 0) {
            format.push(formatNumber(hours))
        }
        if (minutes > 0) {
            format.push(formatNumber(minutes))
        }
        if (seconds >= 0) {
            format.push(formatNumber(seconds))
        }
        return format.join(':')
    }
    return result
}

export const timeUsage = (number) => {
    let result = '00分钟'
    if (number > 0) {
        let hours = Math.floor(number / 3600)
        let minutes = Math.floor((number - hours * 3600) / 60)
        let seconds = number % 60
        let format = []
        if (hours > 0) {
            format.push(`${hours}时`)
        }
        if (minutes > 0) {
            format.push(`${minutes}分`)
        }
        if (seconds > 0) {
            format.push(`${seconds}秒`)
        }
        result = format.join('')
    }
    return result
}

export const humanNumber = (number) => {
    let result = number
    if (number > 10000) {
        result = (number / 10000).toFixed(1) + '万'
    }
    return result
}

export const anonymous = (str, start = 0, length = 4) => {
    str = String(str)
    let end = start + length
    let result = []
    for (let i = 0; i < str.length; i++) {
        result[i] = i >= start && i < end ? '*' : str[i]
    }
    return result.join('')
}

export const thumbAvatar = (url) => {
    return `${url}!avatar_160`
}

export const thumbCover = (url) => {
    return `${url}!cover_270`
}

export const thumbSlide = (url) => {
    return `${url}!slide_1100`
}

export const courseModel = (model) => {
    const mapping = {
        '1': '点播',
        '2': '直播',
        '3': '图文',
        '4': '面授',
    }
    return mapping[model] ? mapping[model] : '未知'
}

export const courseLevel = (level) => {
    const mapping = {
        '1': '入门',
        '2': '初级',
        '3': '中级',
        '4': '高级',
    }
    return mapping[level] ? mapping[level] : '未知'
}

export const examPaperLevel = (level) => {
    const mapping = {
        '1': '初级',
        '2': '中级',
        '3': '高级',
    }
    return mapping[level] ? mapping[level] : '未知'
}

export const examQuestionLevel = (level) => {
    const mapping = {
        '1': '初级',
        '2': '中级',
        '3': '高级',
    }
    return mapping[level] ? mapping[level] : '未知'
}

export const examQuestionModel = (model) => {
    const mapping = {
        '1': '单择题',
        '2': '多选题',
        '3': '判断题',
        '4': '填空题',
        '5': '简答题',
        '9': '题帽题',
    }
    return mapping[model] ? mapping[model] : '未知'
}

export const examType = (type = null) => {
    const mapping = {
        '1': '模拟考试',
        '2': '同步练习',
    }
    if (type == null) return mapping
    return mapping[type] ? mapping[type] : '未知'
}

export const examStatus = (status) => {
    const mapping = {
        '1': '未开始',
        '2': '进行中',
        '3': '待批阅',
        '4': '已完成',
    }
    return mapping[status] ? mapping[status] : '未知'
}

export const redirect = (url, params = {}) => {
    const tabUrls = [
        '/pages/index/index',
        '/pages/course/list',
        '/pages/notification/index',
        '/pages/me/index',
    ]
    if (tabUrls.indexOf(url) != -1) {
        uni.switchTab({
            url: url
        })
        return false
    }
    if (Object.keys(params).length > 0) {
        if (url.indexOf('?') == -1) {
            url += '?' + httpBuildQuery(params)
        } else {
            url += '&' + httpBuildQuery(params)
        }
    }
    if (url.includes('://')) {
        uni.navigateTo({
            url: '/pages/page/web-view?url=' + encodeURIComponent(url)
        })
    } else if (url.startsWith('/pages')) {
        uni.navigateTo({
            url: url
        })
    } else {
        uni.showToast({
            title: '不支持的协议类型'
        })
    }
}

export const getPlatform = () => {
    let platform = 'OTHER'
    // #ifdef H5
    platform = 'H5'
    // #endif
    return platform
}

const httpBuildQuery = (params) => {
    let result = ''
    if (Object.keys(params).length > 0) {
        let arr = []
        for (let key in params) {
            arr.push(`${key}=${params[key]}`)
        }
        result = arr.sort().join('&')
    }
    return result
}

export const getApiBaseUrl = () => {
    return Config.apiBaseUrl
}

export const getToken = () => {
    let key = Storage.cacheKey.token
    return Storage.get(key)
}

export const setToken = (value) => {
    let key = Storage.cacheKey.token
    return Storage.set(key, value)
}

export const clearToken = (value) => {
    let key = Storage.cacheKey.token
    return Storage.set(key, '')
}

export const isLogin = () => {
    if (getToken() == '') {
        return false
    }
    return true
}

export const checkLogin = (opt = {}) => {
    let redirect = '/pages/index/index'
    if (opt.redirect && opt.redirect != '') {
        redirect = opt.redirect
    }
    if (getToken() == '') {
        uni.navigateTo({
            url: '/pages/account/login?redirect=' + encodeURIComponent(redirect)
        })
        return false
    }
    if (opt.success && typeof opt.success == 'function') {
        opt.success()
    }
}
